:mod:`zope.meta` Documentation
==============================

This package provides helper functions and scripts to maintain package
configurations for the Zope Foundation packages.

Contents:

.. toctree::
   :maxdepth: 2

   narr
   api
   hacking



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

